searchData={"items":[{"type":"module","title":"O11y","doc":"A module to help with OpenTelemetry tracing.","ref":"O11y.html"},{"type":"function","title":"O11y.set_attribute/2","doc":"Sets the given attribute on the current span. If the value is not a valid OTLP type,\nit will be converted to a string with `inspect`.\n\nThis method does not support structs to maps, regardless of whether the struct implements the O11y.SpanAttributes protocol.\nYou need to use `set_attributes/1` for that.\n\nExample:\n\n  iex> set_attribute(\"key\", \"value\")","ref":"O11y.html#set_attribute/2"},{"type":"function","title":"O11y.set_attributes/1","doc":"Adds the given attributes as a list, map, or struct to the current span.\nIf the value is a maps or struct, it will be converted to a list of key-value pairs.\nIf the struct derives the O11y.SpanAttributes protocol, it will honor the except and only options.\n\nExample:\n\n  iex> set_attributes(%{key: \"value\"})","ref":"O11y.html#set_attributes/1"},{"type":"function","title":"O11y.set_attributes/2","doc":"Same as set_attributes/1, but with a prefix for all keys.\n\nExample:\n\n  iex> set_attributes(\"my_prefix\", %{key: \"value\"})","ref":"O11y.html#set_attributes/2"},{"type":"protocol","title":"O11y.SpanAttributes","doc":"Defines a protocol for returning opentelemetry span attributes from an object.\nThe easiest way to use this is to use the `@derive` attribute on a struct as shown below,\nbut you can also implement the protocol manually if you need to define custom behavior.\n\nWith the basic derive, all fields in the struct will be returned as attributes:\n```elixir\ndefmodule Basic do\n  @derive O11y.SpanAttributes\n  defstruct [:id, :name]\nend\n```\n\nYou can also use the `only` and `except` options to include or exclude specific fields:\n```elixir\ndefmodule Only do\n  @derive {O11y.SpanAttributes, only: [:id, :name]}\n  defstruct [:id, :name, :email, :password]\nend\n```\n\n```elixir\ndefmodule Except do\n  @derive {O11y.SpanAttributes, except: [:email, :password]}\n  defstruct [:id, :name, :email, :password]\nend\n```\n\nOr you can manually implement the protocol for a struct:\n```elixir\ndefmodule Fancy do\n  defstruct [:url, :token]\nend\n\ndefimpl O11y.SpanAttributes, for: Fancy do\n  def get(%{url: url, token: token}) do\n    masked_token = token |> String.slice(-4, 4) |> String.pad_leading(String.length(token), \"*\")\n    [{\"url\", url}, {\"token\", masked_token}]\n  end\nend\n```","ref":"O11y.SpanAttributes.html"},{"type":"function","title":"O11y.SpanAttributes.get/1","doc":"Returns the opentelemetry span attributes for the given object as a list of tuples.","ref":"O11y.SpanAttributes.html#get/1"},{"type":"type","title":"O11y.SpanAttributes.t/0","doc":"All the types that implement this protocol.","ref":"O11y.SpanAttributes.html#t:t/0"}],"content_type":"text/markdown"}